Index: third_party/WebKit/Source/core/layout/MultiColumnFragmentainerGroup.h |
diff --git a/third_party/WebKit/Source/core/layout/MultiColumnFragmentainerGroup.h b/third_party/WebKit/Source/core/layout/MultiColumnFragmentainerGroup.h |
index c68d35c8fa593f0e5fbb204e798da818608a75b5..e1ca9abfb033b437823dacbe081332bfcfe7ec5b 100644 |
--- a/third_party/WebKit/Source/core/layout/MultiColumnFragmentainerGroup.h |
+++ b/third_party/WebKit/Source/core/layout/MultiColumnFragmentainerGroup.h |
@@ -44,9 +44,9 @@ public: |
LayoutSize offsetFromColumnSet() const; |
- // Return the block offset from the enclosing flow thread, if nested. In the coordinate space |
- // of the enclosing flow thread. |
- LayoutUnit blockOffsetInEnclosingFlowThread() const; |
+ // Return the block offset from the enclosing fragmentation context, if nested. In the |
+ // coordinate space of the enclosing fragmentation context. |
+ LayoutUnit blockOffsetInEnclosingFragmentationContext() const; |
// The top of our flow thread portion |
LayoutUnit logicalTopInFlowThread() const { return m_logicalTopInFlowThread; } |